from fastapi import APIRouter, Depends

from test_api.services.auth import get_current_user

from ..di import get_user_service
from ..schemas import RefDTO, UserDTO, UserReadDTO
from ..services import UserService

router = APIRouter(
    prefix="/user",
)


@router.get("/me", response_model=UserReadDTO, tags=["user"])
async def get_user(
    user_service: UserService = Depends(get_user_service),
    user: UserDTO = Depends(get_current_user),
) -> UserReadDTO | None:
    return await user_service.get_user(email=user.email)


@router.get("/me/create_ref", status_code=201, response_model=RefDTO)
async def create_refer_code(
    user_service: UserService = Depends(get_user_service),
    user: UserDTO = Depends(get_current_user),
) -> RefDTO | None:
    return await user_service.create_refer_code(email=user.email)
